"""A router product type."""

from orchestrator.domain.base import SubscriptionModel
from orchestrator.types import SubscriptionLifecycle
from pydantic_forms.types import strEnum

from gso.products.product_blocks.router import (
    RouterBlock,
    RouterBlockInactive,
    RouterBlockProvisioning,
)


class RouterVendor(strEnum):
    """Enumerator for the different product vendors that are supported."""

    JUNIPER = "juniper"
    NOKIA = "nokia"


class RouterInactive(SubscriptionModel, is_base=True):
    """An inactive router."""

    vendor: RouterVendor
    router: RouterBlockInactive


class RouterProvisioning(RouterInactive, lifecycle=[SubscriptionLifecycle.PROVISIONING]):
    """A router that is being provisioned."""

    vendor: RouterVendor
    router: RouterBlockProvisioning


class Router(RouterProvisioning, lifecycle=[SubscriptionLifecycle.ACTIVE]):
    """A router that is currently active."""

    vendor: RouterVendor
    router: RouterBlock
